defmodule Prymn.Agents do
  alias Prymn.Agents

  def from_server(%Prymn.Servers.Server{} = server) do
    agent_id = to_string(server.id)
    Phoenix.PubSub.subscribe(Prymn.PubSub, "agent:#{agent_id}")
    Agents.Store.get_or_default(agent_id)
  end

  def from_servers(servers) when is_list(servers) do
    Enum.reduce(servers, [], fn server, acc ->
      [{server.id, from_server(server)} | acc]
    end)
    |> Map.new()
  end

  def update_health(agent_id, health) when is_binary(agent_id) do
    agent = Agents.Store.update_health(agent_id, health)
    Phoenix.PubSub.broadcast!(Prymn.PubSub, "agent:#{agent_id}", agent)
  end
end
